@@ -1,12 +1,19 @@
 pub mod parser;
-
-use crate::{BreakPointSystem, CssAttribute, FontSystem, PaletteSystem, PreflightSystem, Result, TailwindInstance};
-use itertools::Itertools;
-
-use std::{
-    collections::{BTreeSet, HashSet},
-    fmt::Debug,
+use crate::{
+    traits::ParsedList, BreakPointSystem, CssAttribute, FontSystem, PaletteSystem, PreflightSystem, Result, TailWindZIndex,
+    TailwindAspect, TailwindBorderCollapse, TailwindBreak, TailwindInstance, TailwindTableLayout,
 };
+use itertools::Itertools;
+use nom::{
+    branch::alt,
+    bytes::complete::tag,
+    character::complete::{alpha1, digit1, space0},
+    combinator::opt,
+    multi::many0,
+    sequence::tuple,
+    IResult,
+};
+use std::{collections::BTreeSet, fmt::Debug};
 
 #[derive(Debug)]
 pub struct TailwindBuilder {
@@ -34,28 +41,35 @@ impl TailwindBuilder {
     pub fn clear(&mut self) {
         self.buffer.clear()
     }
+    #[inline]
     #[track_caller]
     pub fn trace(&mut self, style: &str) -> String {
-        let parsed = self.parse(style);
+        self.try_trace(style).unwrap()
+    }
+    pub fn try_trace(&mut self, style: &str) -> Result<String> {
+        let parsed = self.parse(style)?;
         let out = parsed.iter().map(|s| s.id()).join(" ");
         // self.buffer.extend(parsed.into_iter());
         for i in parsed.into_iter() {
             self.buffer.insert(i);
         }
-        return out;
+        return Ok(out);
     }
 
     pub fn inline(&self, style: &str) -> BTreeSet<CssAttribute> {
         let mut out = BTreeSet::new();
-        for item in self.parse(style) {
+        for item in self.parse(style).unwrap_or_default() {
             out.extend(item.attributes())
         }
         return out;
     }
-    pub fn bundle(&self) -> Result<String> {
-        let mut out = String::with_capacity(1024 * 10);
-        self.preflight.write_css(&mut out)?;
+    pub fn bundle(&self) -> String {
+        self.bundle_buffer(1024 * 10).unwrap_or_default()
+    }
 
+    fn bundle_buffer(&self, cap: usize) -> Result<String> {
+        let mut out = String::with_capacity(cap);
+        self.preflight.write_css(&mut out)?;
         for item in &self.buffer {
             item.write_css(&mut out)?;
         }
