@@ -1,25 +1,23 @@
-use crate::{
-    systems::ParsedList, TailwindAspect, TailwindBorderCollapse, TailwindBreak, TailwindBuilder, TailwindInstance,
-    TailwindTableLayout,
-};
-use nom::{
-    branch::alt,
-    bytes::complete::tag,
-    character::complete::{alpha1, digit1, space0},
-    combinator::opt,
-    multi::many0,
-    sequence::tuple,
-    IResult,
-};
-use std::collections::{BTreeSet, HashSet};
+use crate::systems::spaces::TailwindSpacing;
+use super::*;
 
 impl TailwindBuilder {
     /// `(item (WS item)*)?`
-    pub(crate) fn parse(&self, input: &str) -> BTreeSet<Box<dyn TailwindInstance>> {
+    pub(crate) fn parse(&self, input: &str) -> Result<BTreeSet<Box<dyn TailwindInstance>>> {
         let mut out = BTreeSet::new();
         // FIXME: stupid code !!!
-        let item0 = alt((self.maybe_layout_system(), self.maybe_table_system()));
-        let item = alt((self.maybe_layout_system(), self.maybe_table_system()));
+        let item0 = alt((
+            //
+            self.maybe_layout_system(),
+            self.maybe_spacing_system(),
+            self.maybe_table_system(),
+        ));
+        let item = alt((
+            //
+            self.maybe_layout_system(),
+            self.maybe_spacing_system(),
+            self.maybe_table_system(),
+        ));
         match opt(tuple((item0, many0(tuple((space0, item))))))(input.trim()) {
             Ok((_, None)) => {}
             Ok((_, Some((head, rest)))) => {
@@ -30,16 +28,24 @@ impl TailwindBuilder {
             }
             Err(_) => todo!(),
         };
-        return out;
+        return Ok(out);
     }
 
     fn maybe_layout_system<'a>(&self) -> impl FnMut(&'a str) -> ParsedList<'a> {
-        alt((TailwindAspect::parser(), TailwindBreak::parser()))
+        alt((
+            //
+            TailwindAspect::parser(),
+            TailwindBreak::parser(),
+            TailWindZIndex::parser(),
+        ))
     }
 
     fn maybe_table_system<'a>(&self) -> impl FnMut(&'a str) -> ParsedList<'a> {
         alt((TailwindBorderCollapse::parser(), TailwindTableLayout::parser()))
     }
+    fn maybe_spacing_system<'a>(&self) -> impl FnMut(&'a str) -> ParsedList<'a> {
+        TailwindSpacing::parser()
+    }
 }
 
 fn parse_text(input: &str) -> IResult<&str, (&str, &str)> {
