@@ -7,7 +7,7 @@ impl Default for PaletteSystem {
 }
 
 impl Display for Palette {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
         todo!()
     }
 }
