@@ -1,15 +1,22 @@
 pub mod attribute;
 pub mod instance;
+pub mod object;
 
 use crate::Result;
+use nom::{bytes::complete::tag, IResult};
 use std::{
     cmp::Ordering,
-    collections::BTreeSet,
+    collections::{BTreeSet, HashSet},
     fmt::{Debug, Display, Formatter, Write},
     hash::{Hash, Hasher},
 };
 use text_utils::indent;
 
+/// Tailwind Parsed Result
+pub type ParsedItem<'a> = IResult<&'a str, Box<dyn TailwindInstance>>;
+/// Tailwind Parsed Result
+pub type ParsedList<'a> = IResult<&'a str, HashSet<Box<dyn TailwindInstance>>>;
+
 pub trait TailwindInstance {
     /// used to deduplication and marking
     fn id(&self) -> String;
@@ -32,8 +39,16 @@ pub trait TailwindInstance {
     }
 }
 
-#[derive(Debug, Clone)]
+///
+#[derive(Clone)]
 pub struct CssAttribute {
     key: String,
     value: String,
 }
+
+/// Uncategorized tailwind property
+#[derive(Debug)]
+pub struct TailwindObject {
+    pub id: String,
+    pub attributes: BTreeSet<CssAttribute>,
+}
